/*************************************************************************
  StarTab.c
  Based on data from Burnham's Celestial Handbook.
  This file was derived from the data files of 
  an AmigaBasic version of StarChart, Designed and programmed by Robert L. Hill
  
  
  Credits for Star Chart:
       Robert L. Hill of the Orange County, CA. Amiga Friends User Group
                      wrote the original version of StarChart in AmigaBasic
                      The star data and many of the main functions of this
                      version are derived from that program.

       Ray R. Larson  wrote the c version 1.0 of StarChart, 'intuitionizing'
                      and enhancing the speed and functions of the original.

  Copyright (c) 1986 by Ray R. Larson
  
  This program may be freely distributed and copied, but may not be sold
  without the permission of the author. If you modify or enhance it, 
  please include the above credits (and please send me a copy!).

Ray R. Larson
6425 Central Ave. #304
El Cerrito, CA 94530

BitNet  LARSON@UCBCMSA
=========================================================================*/
#include "star.h"

/* The following is the table containing all star data */  
struct star_rec StarTable[MAXSTARS] = {
{" ", 0.0, 0.0, 0.0, 0.0, 0, 0, " "}, /* dummy zero record */
{ "ALPHERATZ",   0.100,   28.800,    2.100,    0.120,
   1,    1,"White-purple - Head of the Woman in Chains" },
{ "CAPH",   0.110,   58.870,    2.300,    0.045,
  15,    2,"White - Camel Hump or The Hand" },
{ "ALGENIB",   0.170,   14.900,    2.800,    0.570,
  43,    3,"Blue giant - The Wing or Flank" },
{ "DENEB AL SCHEMALI",   0.270,   -9.100,    3.500,    0.540,
  18,    9,"Orange - Tail of the Monster" },
{ "NGC-104",   0.350,  -72.350,    4.500,   20.000,
  55,    0,"Globular cluster" },
{ "ANKAA",   0.420,  -42.500,    2.400,    0.093,
  45,    1,"Orange" },
{ "PI AND",   0.570,   33.450,    4.400,    0.350,
   1,   16,"Blue" },
{ "DELTA AND",   0.610,   30.580,    3.300,    0.160,
   1,    4,"Orange giant" },
{ "SCHEDAR",   0.620,   56.270,    2.200,    0.200,
  15,    1,"Bright orange - The Breast" },
{ "NGC-188",   0.660,   85.050,    9.300,    5.000,
  17,    0,"Open cluster" },
{ "M-31",   0.670,   41.000,    5.000, 2200.000,
   1,    0,"Spiral galaxy - Great Andromeda Galaxy" },
{ "M-32",   0.670,   40.600,    9.500,    0.000,
   1,    0,"Elliptical galaxy companion to M-31" },
{ "DIPHDA",   0.680,  -18.270,    2.000,    0.060,
  18,    2,"Yellow giant - Tail of the Whale - aka DENEB KAITOS" },
{ "ZETA AND",   0.730,   24.000,    4.000,    0.100,
   1,    6,"Orange giant binary" },
{ "NGC-246",   0.740,  -12.150,    8.500,    0.000,
  18,    0,"Planetary nebula" },
{ "NGC-247",   0.740,  -21.010,   10.700,    0.000,
  18,    0,"Spiral galaxy" },
{ "ACHIRD",   0.770,   57.550,    3.500,    0.018,
  15,    7,"Yellow-orange binary" },
{ "NUBECULA MINOR",   0.830,  -73.500,    1.500,  200.000,
  55,    0,"Small Magellanic Cloud - NGC-292" },
{ "NAVI",   0.890,   60.450,    2.400,    0.100,
  15,    3,"Blue variable - aka TSIH" },
{ "MARFAK",   1.080,   54.680,    5.200,    0.026,
  15,   12,"Light orange sub-dwarf binary - Elbow" },
{ "ETA CET",   1.100,  -10.450,    3.400,    0.100,
  18,    7,"Orange giant" },
{ "MIRACH",   1.120,   35.350,    2.000,    0.075,
   1,    2,"Red giant - The Girdle" },
{ "ZETA PSC",   1.170,    7.320,    5.000,    0.140,
  46,    6,"Yellow and rose double" },
{ "RUCHBAH",   1.380,   59.990,    2.700,    0.045,
  15,    4,"Yellow-white - The Knee" },
{ "OMEGA AND",   1.410,   45.150,    4.800,    0.135,
   1,   24,"Yellow double" },
{ "ETA PSC",   1.480,   15.090,    3.700,    0.410,
  46,    7,"Yellow double" },
{ "M-103",   1.500,   60.450,    8.000,    8.000,
  15,    0,"Open cluster" },
{ "NGC-615",   1.550,   -7.880,   12.600,    0.000,
  18,    0,"Spiral galaxy" },
{ "M-74",   1.570,   15.530,   11.000, 30000.000,
  46,    0,"Spiral galaxy" },
{ "ACHERNAR",   1.580,  -57.500,    0.500,    0.120,
  28,    1,"Blue giant - Star at the End of the River" },
{ "M-76",   1.640,   51.320,   11.000,    1.750,
  44,    0,"Planetary nebula - The Cork" },
{ "TAU CET",   1.690,  -16.200,    3.500,    0.012,
  18,   19,"Orange" },
{ "POLARIS",   1.810,   89.030,    2.000,    0.360,
  57,    1,"Topaz yellow supergiant double - The Pole Star" },
{ "BATEN KAITOS",   1.820,   -9.700,    3.900,    0.140,
  18,    6,"Topaz yellow - Belly of the Whale" },
{ "MESARTHIM",   1.830,   19.050,    3.900,    0.160,
   5,    3,"Bright white double - The Minister" },
{ "SEGIN",   1.840,   63.420,    3.400,    0.520,
  15,    5,"Blue" },
{ "SHERATAN",   1.870,   20.570,    2.700,    0.052,
   5,    2,"Pearly white binary - The Sign" },
{ "AL RISCHA",   1.990,    2.520,    4.000,    0.130,
  46,    1,"White binary - The Cord or Knot" },
{ "ALMACH",   2.010,   42.100,    2.100,    0.260,
   1,    3,"Orange double - Badger" },
{ "HAMAL",   2.070,   23.230,    2.200,    0.075,
   5,    1,"Orange giant - Head of the Sheep" },
{ "NGC-869",   2.280,   56.900,    7.000,    7.400,
  44,    0,"Double cluster with NGC-884" },
{ "MIRA",   2.280,   -3.200,    3.200,    0.000,
  18,   15,"Flushed yellow giant variable - The Wonderful" },
{ "NGC-884",   2.310,   56.880,    7.000,    7.400,
  44,    0,"Double cluster with NGC-869" },
{ "IOTA CAS",   2.410,   67.180,    4.500,    0.160,
  15,    9,"White-yellow triple" },
{ "M-34",   2.640,   42.470,    6.000,    1.500,
  44,    0,"Open cluster" },
{ "THETA PER",   2.670,   49.020,    4.000,    0.042,
  44,    8,"Yellow binary" },
{ "M-77",   2.670,   -0.230,   10.000, 60000.000,
  18,    0,"Spiral galaxy" },
{ "GAMMA CET",   2.670,    3.030,    3.700,    0.070,
  18,    3,"Yellow double" },
{ "ETA PER",   2.780,   55.680,    3.900,    1.100,
  44,    7,"Yellow and Blue double" },
{ "KERB",   2.840,   52.570,    4.100,    0.000,
  44,   19,"Yellow double" },
{ "AZHA",   2.890,   -7.160,    4.000,    0.135,
  28,    7,"Pale yellow - Ostrich Nest" },
{ "ACAMAR",   2.930,  -40.500,    2.900,    0.115,
  28,    8,"White double" },
{ "MENKAR",   2.990,    3.900,    2.500,    0.150,
  18,    1,"Bright orange giant - The Nose aka MENKAB" },
{ "GAMMA PER",   3.020,   53.320,    2.900,    0.150,
  44,    3,"Orange giant binary" },
{ "RHO PER",   3.030,   38.650,    3.300,    0.260,
  44,   17,"Red giant variable" },
{ "ALGOL",   3.080,   40.770,    2.200,    0.100,
  44,    2,"White variable - The Ghoul" },
{ "IOTA PER",   3.090,   49.400,    4.200,    0.039,
  44,    9,"Yellow-orange" },
{ "BOTEIN",   3.140,   19.500,    4.500,    0.170,
   5,    4,"Orange" },
{ "ANGETENAR",   3.280,  -20.300,    3.900,    0.360,
  28,   19,"Red" },
{ "MIRFAK",   3.340,   49.680,    1.800,    0.570,
  44,    1,"Lilac supergiant - The Elbow" },
{ "XI TAU",   3.400,    9.510,    3.800,    0.190,
  54,   14,"Blue" },
{ "EPSILON ERI",   3.510,   -9.630,    3.700,    0.018,
  28,    5,"Orange" },
{ "THEEMINI",   3.540,  -29.520,    3.900,    0.300,
  28,   20,"Orange multiple" },
{ "DELTA PER",   3.650,   47.630,    3.000,    0.590,
  44,    4,"Blue giant" },
{ "RANA",   3.670,   -8.310,    3.700,    0.029,
  28,    4,"Orange" },
{ "ATI",   3.680,   32.130,    3.800,    1.160,
  44,   15,"Blue - aka ALTIKS" },
{ "NEMBUS",   3.680,   42.400,    3.900,    0.410,
  44,   20,"Blue" },
{ "IC-342",   3.680,   67.950,   12.000,    0.000,
   8,    0,"Spiral galaxy" },
{ "ELECTRA",   3.690,   23.910,    3.800,    0.000,
  54,    0,"Blue - Pleiades" },
{ "TAYGATE",   3.700,   24.260,    4.400,    0.000,
  54,    0,"Blue - Pleiades" },
{ "MAIA",   3.710,   24.160,    4.000,    0.000,
  54,    0,"Blue - Pleiades" },
{ "MEROPE",   3.710,   23.740,    4.300,    0.000,
  54,    0,"Blue - Pleiades" },
{ "M-45",   3.730,   23.970,    1.600,    0.130,
  54,    0,"Pleiades Star Cluster aka The Seven Sisters" },
{ "ALCYONE",   3.750,   23.970,    2.900,    0.000,
  54,    7,"Greenish yellow - brightest of the Pleiades" },
{ "ATLAS",   3.760,   23.850,    3.800,    0.000,
  54,    0,"Blue - Pleiades" },
{ "ATIK",   3.850,   31.730,    2.800,    1.000,
  44,    6,"Blue supergiant - The Shoulder" },
{ "EPSILON PER",   3.910,   39.870,    2.900,    0.680,
  44,    5,"Blue giant double" },
{ "MENKIB",   3.910,   35.600,    4.000,    1.900,
  44,   14,"Blue-white" },
{ "ZUARAK",   3.920,  -13.650,    3.000,    0.260,
  28,    3,"Red giant - Bright Star of the Boat" },
{ "LAMBDA TAU",   3.960,   12.350,    3.900,    0.400,
  54,   11,"White binary" },
{ "NGC-1501",   4.030,   60.780,   12.000,    0.000,
   8,    0,"Planetary nebula" },
{ "NGC-1502",   4.050,   62.180,    8.300,    0.000,
   8,    0,"Open cluster" },
{ "MU PER",   4.180,   48.280,    4.500,    1.250,
  44,   12,"Yellow double" },
{ "BEID",   4.220,   -7.730,    4.500,    0.016,
  28,   15,"Orange giant binary - The Egg" },
{ "HYADUM",   4.300,   15.500,    3.700,    0.000,
  54,    3,"Yellow giant - Nose of the Bull - in Hyades" },
{ "DELTA TAU",   4.330,   17.370,    3.700,    0.000,
  54,    4,"Yellow giant - in Hyades" },
{ "THETA TAU",   4.430,   15.770,    3.300,    0.000,
  54,    8,"Yellow giant double - in Hyades" },
{ "AIN",   4.430,   19.100,    3.500,    0.000,
  54,    5,"Yellow giant - in Hyades" },
{ "ALDEBARAN",   4.550,   16.420,    0.900,    0.068,
  54,    1,"Pale rose giant - Eye of the Bull" },
{ "TAU TAU",   4.650,   22.870,    4.300,    0.105,
  54,   19,"Blue" },
{ "PI ORI",   4.780,    6.880,    3.200,    0.026,
  41,   16,"Yellow" },
{ "ALPHA CAM",   4.810,   60.340,    4.200,    1.700,
   8,    1,"Blue-white" },
{ "HASSALEH",   4.890,   33.080,    2.700,    0.330,
   6,    9,"Orange giant" },
{ "R LEP",   4.950,  -14.880,    5.900,    1.500,
  34,    0,"Red variable - Crimson Star" },
{ "BETA CAM",   4.960,   60.340,    4.200,    1.700,
   8,    2,"Yellow double" },
{ "MAAZ",   4.970,   43.750,    3.000,    3.300,
   6,    5,"White-yellow supergiant binary - The Kids" },
{ "SADATONI",   4.980,   41.000,    3.800,    1.200,
   6,    6,"Orange giant binary - The Kids" },
{ "HOEDUS",   5.050,   41.170,    3.200,    0.370,
   6,    7,"Blue - The Kids" },
{ "NGC-1784",   5.050,  -11.930,   12.600,    0.000,
  34,    0," " },
{ "EPSILON LEP",   5.050,  -22.430,    3.200,    0.170,
  34,    5,"Orange giant" },
{ "CURSA",   5.080,   -5.150,    2.800,    0.080,
  28,    2,"White giant" },
{ "MU LEP",   5.170,  -16.270,    3.300,    0.390,
  34,   12,"Blue" },
{ "RIGEL",   5.210,   -8.250,    0.140,    0.900,
  41,    2,"Blue-white supergiant - Leg of the Jabbah or Giant" },
{ "CAPELLA",   5.220,   45.950,    0.060,    0.045,
   6,    1,"Golden yellow giant - The Mother Goat" },
{ "M-79",   5.370,  -24.570,    8.400,   50.000,
  34,    0,"Globular cluster" },
{ "ETA ORI",   5.370,   -2.430,    3.300,    0.940,
  41,    7,"Blue double" },
{ "BELLATRIX",   5.370,    6.300,    1.600,    0.470,
  41,    3,"Pale yellow giant - Female Warrior" },
{ "EL NATH",   5.380,   28.570,    1.700,    0.300,
  54,    2,"Brilliant white giant - Heel of the Reinholder" },
{ "THABIT",   5.410,   -6.830,    4.600,    1.300,
  41,   20,"Blue" },
{ "M-38",   5.420,   35.800,    8.000,    4.200,
   6,    0,"Open cluster" },
{ "NIHAL",   5.430,  -20.800,    2.800,    0.115,
  34,    2,"Deep yellow giant double" },
{ "NEBECULA MAJOR",   5.430,  -69.000,    1.000,  190.000,
  26,    0,"Large Magellanic Cloud" },
{ "MINTAKA",   5.490,   -0.330,    2.200,    1.500,
  41,    4,"Brilliant white giant - Belt of the Giant" },
{ "ARNEB",   5.500,  -17.850,    2.600,    0.900,
  34,    1,"Pale yellow supergiant - The Hare - aka ARSH" },
{ "M-1",   5.520,   21.980,    8.500,    6.300,
  54,    0,"Supernova remnant - The Crab Nebula" },
{ "CHI 1 ORI",   5.530,   20.130,    4.600,    0.031,
  41,   22,"Blue - Head of Orions Club" },
{ "HEKA",   5.540,    9.900,    3.400,    1.800,
  41,   11,"Pale white double - Head of Orion - aka MEISSA" },
{ "M-36",   5.540,   34.120,    9.000,    4.100,
   6,    0,"Open cluster" },
{ "THETA ORI",   5.550,   -5.400,    5.000,    1.600,
  41,    8,"Four stars in M-42 - Trapezium" },
{ "M-42",   5.550,   -5.400,    5.000,    1.600,
  41,    0,"Diffuse nebula - Orion Nebula" },
{ "HATSYA",   5.550,   -5.930,    2.800,    2.000,
  41,    9,"Bright One of the Sword" },
{ "BETA DOR",   5.550,  -62.520,    4.000,    0.900,
  26,    2,"Yellow supergiant variable" },
{ "ALNILAM",   5.560,   -1.230,    1.700,    1.600,
  41,    5,"Bright white supergiant - Belt of Pearls" },
{ "ZETA TAU",   5.580,   21.120,    3.000,    0.940,
  54,    6,"Blue giant shell star" },
{ "SIGMA ORI",   5.600,   -2.630,    3.700,    1.400,
  41,   18,"Multiple" },
{ "PHACT",   5.620,  -34.100,    2.600,    0.140,
  19,    1,"Blue-white - Heart of the Dove" },
{ "ALNITAK",   5.630,   -1.970,    1.800,    1.600,
  41,    6,"Topaz yellow supergiant - The Girdle" },
{ "NGC-2070",   5.660,  -69.060,    0.800,  190.000,
  26,    0,"Tarantula Nebula" },
{ "GAMMA LEP",   5.700,  -22.470,    3.600,    0.029,
  34,    3,"Yellow double" },
{ "M-78",   5.730,    0.030,    8.000,    1.600,
  41,    0,"Diffuse nebula" },
{ "MU COL",   5.730,  -32.320,    5.200,    0.000,
  19,   12,"Blue - Runaway Star" },
{ "SAIPH",   5.750,   -9.680,    2.100,    2.100,
  41,   10,"Blue supergiant - Sword of the Giant" },
{ "WEZN",   5.820,  -35.780,    3.100,    0.140,
  19,    2,"Orange giant" },
{ "M-37",   5.820,   32.550,    9.000,    4.600,
   6,    0,"Open cluster" },
{ "BETELGEUSE",   5.870,    7.400,    0.700,    0.520,
  41,    1,"Orange supergiant - Armpit of the Central One" },
{ "MENKALINAN",   5.920,   44.950,    1.900,    0.090,
   6,    2,"Lucid yellow binary - Shoulder of the Driver" },
{ "THETA AUR",   5.930,   37.220,    2.700,    0.110,
   6,    8,"Blue-white" },
{ "GEMINI 1",   6.020,   23.270,    4.300,    0.120,
  29,    0,"Yellow binary" },
{ "NGC-2158",   6.060,   24.100,   11.600,   16.000,
  29,    0,"Open cluster - Companion to M-35" },
{ "M-35",   6.080,   24.330,    5.500,    2.200,
  29,    0,"Open cluster" },
{ "TEJAT PRIOR",   6.200,   22.510,    3.400,    0.200,
  29,    7,"Red giant double - aka PROPUS" },
{ "FURUD",   6.310,  -30.000,    3.000,    0.390,
  11,    6,"Blue - Bright Single One" },
{ "TEJAT POSTERIOR",   6.320,   22.550,    2.900,    0.160,
  29,   12,"Red giant variable" },
{ "MURZAM",   6.330,  -17.930,    2.000,    0.750,
  11,    2,"White giant - Announcer" },
{ "PROPUS",   6.370,   22.380,    3.100,    0.200,
  29,    7,"Red variable - Forward Foot" },
{ "CANOPUS",   6.380,  -52.670,   -0.700,    0.120,
  14,    1,"Yellow giant" },
{ "BETA MON",   6.430,   -7.000,    4.600,    0.180,
  39,    2,"Blue-white triple" },
{ "NGC-2237",   6.490,    4.900,    5.000,    2.600,
  39,    0,"Rosette Nebula" },
{ "ALHENA",   6.570,   16.450,    1.900,    0.105,
  29,    3,"White - A Brand on the Camels Neck" },
{ "NGC-2261",   6.600,    8.770,   10.000,    2.600,
  39,    0,"Hubble Variable Nebula" },
{ "NU PUP",   6.600,  -43.150,    3.200,    0.600,
  48,   13,"Blue giant" },
{ "NGC-2264",   6.630,    9.930,    6.000,    2.600,
  39,    0,"Open cluster - Christmas Tree and Cone Nebula" },
{ "MEBSUTA",   6.670,   25.180,    3.000,    1.100,
  29,    5,"Brilliant white supergiant - Outstretched" },
{ "ALZIRR",   6.710,   12.950,    3.400,    0.065,
  29,   14,"Yellow" },
{ "SIRIUS",   6.720,  -16.650,   -1.400,    0.009,
  11,    1,"Blue-white - The Scorcher or Dog Star" },
{ "M-41",   6.750,  -20.700,    7.000,    2.350,
  11,    0,"Open cluster" },
{ "THETA GEM",   6.850,   33.900,    4.000,    0.140,
  29,    8,"White" },
{ "TAU PUP",   6.860,  -50.550,    2.900,    0.125,
  48,   19,"Orange giant" },
{ "E GEM",   6.860,   13.250,    4.700,    0.170,
  29,    0,"Yellow double - aka 38 GEMINI" },
{ "PI CMA",   6.880,  -20.060,    4.600,    0.110,
  11,   16,"Yellow" },
{ "ADHARA",   6.940,  -28.900,    1.500,    0.680,
  11,    5,"Pale orange - The Virgins" },
{ "M-50",   7.000,   -8.270,    6.300,    2.900,
  39,    0,"Open cluster" },
{ "OMICRON CMA",   7.010,  -23.800,    3.000,    3.400,
  11,   15,"Blue supergiant" },
{ "MEKBUDA",   7.020,   20.650,    4.500,    1.500,
  29,    6,"Pale topaz variable - Contracted Arm" },
{ "MULIPHEN",   7.030,  -15.550,    4.100,    1.250,
  11,    3,"Blue-white giant" },
{ "WESEN",   7.100,  -26.320,    1.800,    2.100,
  11,    4,"Light yellow supergiant - Weight" },
{ "OMEGA CMA",   7.200,  -26.770,    3.800,    0.400,
  11,   24,"Blue" },
{ "LAMBDA GEM",   7.250,   16.630,    4.000,    0.075,
  29,   11,"White" },
{ "PI PUP",   7.260,  -37.000,    2.800,    0.140,
  48,   16,"Orange giant" },
{ "UW CMA",   7.270,  -24.470,    5.000,    3.600,
  11,    0,"Blue-white supergiant binary" },
{ "NGC-2362",   7.270,  -24.870,    7.500,    4.600,
  11,    0,"Open cluster" },
{ "WASAT",   7.280,   22.080,    3.500,    0.053,
  29,    4,"Pale white double - The Middle" },
{ "ALUDRA",   7.370,  -29.200,    2.400,    2.700,
  11,    7,"Pale blue supergiant - The Virgins" },
{ "GOMEISA",   7.410,    8.400,    2.800,    0.210,
  12,    2,"White - Watery-Eyed" },
{ "NGC-2392",   7.430,   21.020,    8.600,    3.000,
  29,    0,"Planetary nebula - Eskimo Nebula" },
{ "SIGMA PUP",   7.460,  -43.200,    3.300,    0.130,
  48,   18,"Orange giant double" },
{ "CASTOR",   7.520,   32.000,    1.600,    0.045,
  29,    1,"White-green six doubles - The Horseman" },
{ "NGC-2403",   7.530,   65.720,    8.800, 8000.000,
   8,    0,"Spiral galaxy" },
{ "M-47",   7.570,  -14.370,    5.000,    1.540,
  48,    0,"Open cluster" },
{ "NGC-2419",   7.570,   39.000,   10.900,  182.000,
  37,    0,"Globular cluster - Intergalactic Wanderer" },
{ "NGC-2420",   7.580,   21.680,    9.500,    0.000,
  29,    0,"Open cluster" },
{ "PROCYON",   7.610,    5.350,    0.350,    0.011,
  12,    1,"Yellow-white binary - Foremost Dog" },
{ "M-46",   7.660,  -14.700,    8.000,    3.300,
  48,    0,"Open cluster" },
{ "KAPPA GEM",   7.680,   24.520,    4.000,    0.140,
  29,   10,"Yellow-orange" },
{ "M-93",   7.710,  -23.750,    7.000,    3.400,
  48,    0,"Open cluster" },
{ "POLLUX",   7.710,   28.150,    1.200,    0.035,
  29,    2,"Orange giant - Boxer or Pugilist" },
{ "ASMIDISKE",   7.780,  -24.730,    3.300,    1.200,
  48,   14,"Yellow supergiant" },
{ "NGC-2477",   7.840,  -38.420,    7.000,    2.000,
  48,    0,"Open cluster" },
{ "CHI CAR",   7.920,  -52.850,    3.500,    0.430,
  14,   22,"Blue" },
{ "NGC-2516",   7.990,  -60.730,    7.000,    1.200,
  14,    0,"Open cluster" },
{ "SUHAIL HADAR",   8.030,  -39.870,    2.300,    2.400,
  48,    6,"Supergiant - Ship - aka NAOS" },
{ "TURAIS",   8.080,  -24.170,    2.800,    0.100,
  48,   17,"Yellow giant variable" },
{ "SUHAIL",   8.130,  -47.200,    1.900,    0.520,
  58,    3,"White double - Glorious" },
{ "TEGMENI",   8.150,   17.800,    5.100,    0.070,
   8,    6,"Yellow multiple - In the Covering" },
{ "M-48",   8.180,   -5.630,    5.500,    1.700,
  32,    0,"Open cluster" },
{ "BETA CNC",   8.220,    9.350,    3.800,    0.220,
   9,    2,"Orange" },
{ "AVIOR",   8.360,  -59.350,    1.900,    0.340,
  14,    5,"Orange giant" },
{ "MUSCIDA",   8.430,   60.880,    3.400,    0.150,
  56,   15,"Yellow giant - Muzzle" },
{ "M-44",   8.620,   19.870,    4.500,    0.525,
   9,    0,"Beehive Cluster - aka PRAESEPE" },
{ "ASELLUS BOREALIS",   8.670,   21.600,    4.700,    0.000,
   9,    3,"Straw color - Northern Ass" },
{ "ASELLUS AUSTRALIS",   8.700,   18.350,    4.200,    0.000,
   9,    4,"Straw color - Southern Ass" },
{ "KOO SHE",   8.720,  -54.520,    2.000,    0.075,
  58,    4,"White" },
{ "EPSILON HYA",   8.730,    6.600,    3.400,    0.140,
  32,    5,"Yellow giant multiple" },
{ "IOTA CNC",   8.730,   28.950,    4.500,    0.170,
   9,    9,"Yellow-blue" },
{ "M-67",   8.810,   12.000,   10.000,    2.500,
   9,    0,"Open cluster" },
{ "NGC-2683",   8.820,   33.630,   10.600,    0.000,
  37,    0,"Spiral galaxy - nearly edge on" },
{ "ZETA HYA",   8.870,    6.130,    3.100,    0.220,
  32,    6,"Orange giant" },
{ "TALITHA",   8.920,   48.230,    3.100,    0.050,
  56,    9,"Yellow binary - Third Leap" },
{ "ACUBENS",   8.930,   12.050,    4.500,    0.100,
   9,    1,"White - The Claws - aka SERTAN" },
{ "KAPPA UMA",   9.000,   47.350,    3.700,    0.300,
  56,   10,"Blue binary" },
{ "ALSUHAIL",   9.100,  -43.230,    2.200,    0.750,
  58,   11,"Orange supergiant - Weight" },
{ "SIGMA UMA",   9.100,   67.330,    4.800,    0.060,
  56,   18,"Yellow binary" },
{ "MIAPLACIDUS",   9.210,  -69.520,    1.700,    0.085,
  14,    2,"White" },
{ "TUREIS",   9.260,  -59.000,    2.200,    0.750,
  14,    9,"Yellow supergiant" },
{ "ALSCIAUKAT",   9.310,   34.600,    3.100,    0.155,
  37,    1,"Red giant" },
{ "MARKEB",   9.340,  -54.800,    2.500,    0.470,
  58,   10,"Blue binary" },
{ "KAPPA LEO",   9.350,   26.400,    5.000,    0.330,
  33,   10,"Orange giant" },
{ "OMEGA LEO",   9.420,    9.280,    6.000,    0.000,
  33,   24,"Binary" },
{ "ALPHARD",   9.420,   -8.430,    2.000,    0.095,
  32,    1,"Orange giant - Lonely One in the Serpent" },
{ "ALTERF",   9.490,   22.930,    4.500,    0.180,
  33,   11,"Red - The Glance" },
{ "NGC-2903",   9.490,   21.730,    9.700,    0.000,
  33,    0,"Spiral galaxy" },
{ "THETA UMA",   9.500,   51.920,    3.200,    0.065,
  56,    8,"Yellow" },
{ "SUBRA",   9.630,   10.120,    4.000,    0.175,
  33,   15,"White double" },
{ "RAS ELASED",   9.720,   24.000,    3.000,    0.340,
  33,    5,"Yellow giant - Head of the Lion - aka ALGENUBI" },
{ "UPSILON CAR",   9.760,  -64.830,    2.900,    0.340,
  14,   20,"White double" },
{ "PHI UMA",   9.810,   54.300,    4.500,    0.120,
  56,   21,"White binary" },
{ "RASALAS",   9.850,   26.200,    4.100,    0.160,
  33,   12,"Orange - Lion Head Toward the South" },
{ "M-81",   9.860,   69.300,    8.000, 7000.000,
  56,    0,"Spiral galaxy" },
{ "M-82",   9.860,   69.900,    9.200,    0.000,
  56,    0,"Spiral galaxy" },
{ "ETA LEO",  10.070,   17.000,    3.500,    2.000,
  33,    7,"White giant" },
{ "REGULUS",  10.080,   12.220,    1.300,    0.085,
  33,    1,"White - Little King - Handle of the Sickle" },
{ "OMEGA CAR",  10.170,  -69.780,    3.400,    0.300,
  14,   24,"Blue" },
{ "ALDHAFERA",  10.220,   23.670,    3.400,    0.130,
  33,    6,"Yellow giant - Sickle" },
{ "TANIA BOREALIS",  10.230,   43.170,    3.500,    0.150,
  56,   11,"White - Second Leap" },
{ "AL GEIBA",  10.280,   20.100,    2.000,    0.090,
  33,    3,"Orange giant double - The Mane" },
{ "TANIA AUSTRALIS",  10.320,   41.750,    3.000,    0.105,
  56,   12,"Red giant binary" },
{ "NGC-3242",  10.370,  -18.380,    9.000,    3.300,
  32,    0,"Planetary nebula" },
{ "M-95",  10.680,   11.970,   11.000,    0.000,
  33,    0,"Spiral galaxy - pair with M-96" },
{ "THETA CAR",  10.680,  -64.130,    2.700,    0.700,
  14,    8,"Blue" },
{ "ETA CAR",  10.720,  -59.420,    7.000,    3.700,
  14,    7,"Yellow variable - Nova in KEY-HOLE NEBULA" },
{ "NGC-3372",  10.720,  -59.420,   10.000,    0.000,
  14,    0,"Key-hole Nebula" },
{ "M-96",  10.730,   12.080,   10.200,    0.000,
  33,    0,"Spiral galaxy - pair with M-95" },
{ "MU VELA",  10.750,  -49.150,    2.800,    0.110,
  58,   12,"Yellow giant binary" },
{ "NU HYA",  10.780,  -15.930,    3.100,    0.150,
  32,   13,"Orange giant" },
{ "MERAK",  10.970,   56.650,    2.400,    0.080,
  56,    2,"Greenish-white - Loin of the Bear -  Pointer to Polaris" },
{ "DUBHE",  11.000,   62.020,    1.800,    0.105,
  56,    1,"Yellow giant - A Bear - Pointer to Polaris" },
{ "CHI LEO",  11.030,    7.620,    4.500,    0.180,
  33,   22,"Yellow double" },
{ "CHI HYA",  11.050,  -27.020,    5.000,    0.090,
  32,   22,"Yellow binary" },
{ "NGC-3532",  11.050,  -58.400,    8.000,    1.300,
  14,    0,"Open cluster" },
{ "PSI UMA",  11.110,   44.770,    3.000,    0.130,
  56,   23,"Yellow giant" },
{ "COXA",  11.180,   15.700,    3.300,    0.090,
  33,    8,"White - aka CHORT" },
{ "ZOSMA",  11.180,   20.800,    2.600,    0.080,
  33,    4,"Pale yellow - A Girdle - aka DUHR or ZUBRA" },
{ "M-97",  11.200,   55.300,   11.000,    3.000,
  56,    0,"Planetary nebula - Owl Nebula" },
{ "ALULA AUSTRALIS",  11.260,   31.820,    3.700,    0.026,
  56,   14,"Yellow binary - First Spring" },
{ "ALULA BOREALIS",  11.270,   33.010,    3.700,    0.270,
  56,   13,"Orange - Northern Wing" },
{ "M-65",  11.270,   13.380,   10.300,    0.000,
  33,    0,"Spiral galaxy - pair with M-66" },
{ "M-66",  11.280,   13.280,    9.700,    0.000,
  33,    0,"Spiral galaxy - pair with M-65" },
{ "IOTA LEO",  11.350,   10.800,    4.000,    0.070,
  33,    9,"Yellow binary" },
{ "TAU LEO",  11.420,    3.130,    5.500,    0.000,
  33,   19,"Orange double" },
{ "GIANSAR",  11.480,   69.400,    4.100,    0.190,
  27,   11,"Orange - Poison Place" },
{ "LAMBDA CEN",  11.560,  -62.750,    3.200,    0.370,
  16,   11,"Blue giant" },
{ "NGC-3766",  11.570,  -61.320,    5.100,    0.000,
  16,    0,"Open cluster" },
{ "ALKAFZAH",  11.730,   47.800,    3.900,    0.180,
  56,   22,"Orange" },
{ "DENEBOLA",  11.760,   14.850,    2.100,    0.043,
  33,    2,"Blue double - Lions Tail - aka DAFIRA" },
{ "NGC-3918",  11.790,  -56.900,    8.400,    0.000,
  16,    0,"Planetary nebula" },
{ "ZAWIJAH",  11.800,    1.740,    3.800,    0.032,
  59,    2,"Pale yellow - The Corner" },
{ "PHECDA",  11.850,   53.970,    2.400,    0.090,
  56,    3,"Topaz yellow - Thigh of the Bear - aka PHAD" },
{ "NGC-4038",  11.990,  -18.580,   11.000, 90000.000,
  22,    0,"Spiral galaxy - Ring Tail Galaxy" },
{ "DELTA CEN",  12.090,  -50.450,    2.600,    0.370,
  16,    4,"Blue shell star" },
{ "ALCHIBA",  12.100,  -23.530,    4.200,    0.060,
  22,    1,"Yellow" },
{ "EPSILON CRV",  12.120,  -22.350,    3.000,    0.140,
  22,    5,"Orange giant" },
{ "M-98",  12.180,   15.180,   10.700, 35000.000,
  20,    0,"Elongated spiral galaxy" },
{ "CRUCIS",  12.210,  -58.470,    2.800,    0.570,
  23,    4,"Blue" },
{ "MEGREZ",  12.220,   57.320,    3.300,    0.065,
  56,    4,"Pale yellow - Root of the Bears Tail" },
{ "GIENAH",  12.220,  -17.270,    2.600,    0.450,
  22,    3,"Blue-white giant - Right Wing of the Raven" },
{ "NGC-4258",  12.270,   47.580,    9.000,    0.000,
  10,    0,"Spiral galaxy" },
{ "M-99",  12.270,   14.700,   10.500, 50000.000,
  20,    0,"Round spiral galaxy" },
{ "M-61",  12.320,    4.750,   10.200, 42000.000,
  59,    0,"Spiral galaxy in Virgo Cluster" },
{ "M-100",  12.330,   16.100,   10.600, 40000.000,
  20,    0,"Spiral galaxy" },
{ "COMA CLUSTER",  12.370,   26.000,    3.200,    0.250,
  20,    0,"Galactic cluster" },
{ "M-85",  12.380,   18.470,   10.500, 41000.000,
  20,    0,"Eliptic galaxy" },
{ "NGC-4394",  12.380,   18.480,   11.700,    0.000,
  20,    0,"Barred spiral galaxy" },
{ "M-84",  12.380,   13.170,   10.500, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "M-86",  12.390,   13.220,   10.500, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "ACRUX",  12.390,  -62.820,    0.900,    0.370,
  23,    1,"Blue double" },
{ "M-49",  12.450,    8.270,   10.100, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "ALGORAB",  12.450,  -16.230,    3.000,    0.125,
  22,    4,"White double - Raven" },
{ "GAMMA CRU",  12.470,  -56.830,    1.700,    0.220,
  23,    3,"Red giant" },
{ "M-87",  12.470,   12.670,   10.100, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "M-88",  12.490,   14.700,   10.500, 41000.000,
  20,    0,"Spiral galaxy" },
{ "KRAZ",  12.530,  -23.120,    2.700,    0.110,
  22,    2,"Yellow-orange giant" },
{ "M-89",  12.550,   12.830,   11.000, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "NGC-4565",  12.560,   26.270,   10.500, 20000.000,
  20,    0,"Spiral galaxy" },
{ "M-90",  12.570,   13.430,   11.100, 42000.000,
  59,    0,"Spiral galaxy in Virgo Cluster" },
{ "M-58",  12.580,   12.080,   10.500, 42000.000,
  59,    0,"Barred spiral galaxy in Virgo Cluster" },
{ "M-68",  12.610,  -26.480,    8.000,   46.000,
  32,    0,"Globular cluster" },
{ "M-104",  12.620,  -11.350,    8.200, 42000.000,
  59,    0,"Spiral in Virgo Cluster - Sombrero Galaxy" },
{ "MUHLIFAIN",  12.640,  -48.680,    2.200,    0.160,
  16,    3,"White giant binary" },
{ "PORRIMA",  12.650,   -1.180,    2.800,    0.032,
  59,    3,"Yellow binary - Goddess of Prophecy" },
{ "M-59",  12.660,   11.920,   11.000, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "M-60",  12.680,   11.820,   10.000, 42000.000,
  59,    0,"Elliptical galaxy in Virgo Cluster" },
{ "MIMOSA",  12.740,  -59.420,    1.500,    0.490,
  23,    2,"Blue variable" },
{ "ZANIAH",  12.790,   -0.670,    4.000,    0.125,
  59,    7,"White" },
{ "M-94",  12.810,   41.380,    8.900, 20000.000,
  10,    0,"Spiral galaxy" },
{ "NGC-4755",  12.840,  -60.080,    6.000,    7.700,
  23,    0,"Open cluster - Jewel Box" },
{ "ALIOTH",  12.860,   56.230,    1.800,    0.070,
  56,    5,"White - Tail of the Great Bear" },
{ "MINELAUVA",  12.880,    3.670,    3.700,    0.180,
  59,    4,"Red giant" },
{ "COR CAROLI",  12.890,   38.580,    2.900,    0.120,
  10,    1,"Flushed white double - Heart of Charles" },
{ "M-64",  12.900,   21.950,    8.000, 25000.000,
  20,    0,"Spiral galaxy - The Black Eye Galaxy" },
{ "VINDEMIATRIX",  12.990,   11.230,    2.800,    0.090,
  59,    5,"Bright yellow giant - Grape Gatherer" },
{ "NGC-4945",  13.030,  -49.220,    9.200,    0.000,
  16,    0,"Barred spiral galaxy" },
{ "DIADEM",  13.120,   17.800,    4.200,    0.065,
  20,    1,"Yellow double" },
{ "M-53",  13.170,   18.430,    7.700,   65.000,
  20,    0,"Globular cluster" },
{ "NGC-5053",  13.220,   17.950,   10.500,   55.000,
  20,    0,"Globular cluster" },
{ "M-63",  13.220,   42.280,    9.500, 35000.000,
  10,    0,"Spiral galaxy - The Sunflower" },
{ "GAMMA HYA",  13.270,  -22.900,    3.000,    0.115,
  32,    3,"Yellow-orange giant" },
{ "IOTA CEN",  13.290,  -36.450,    2.800,    0.070,
  16,    9,"White" },
{ "NGC-5102",  13.320,  -36.380,   10.800,    0.000,
  16,    0,"Spiral galaxy" },
{ "MIZAR",  13.360,   55.180,    2.400,    0.088,
  56,    6,"Brilliant white double - A Girdle or Apron" },
{ "SPICA",  13.370,  -10.900,    1.000,    0.275,
  59,    1,"Brilliant flushed-white - Ear of Wheat or Corn" },
{ "NGC-5128",  13.370,  -42.750,    7.200, 25000.000,
  16,    0,"Lenticular galaxy - Centaurus-A" },
{ "ALCOR",  13.380,   55.020,    4.000,    0.084,
  56,    0,"Silver-white - Rider or Proof aka G UMA" },
{ "NGC-5139",  13.390,  -47.220,    3.800,   22.000,
  16,    0,"Globular cluster - Omega Centauri" },
{ "M-51",  13.460,   47.450,    8.700, 35000.000,
  10,    0,"Spiral galaxy - The Whirlpool Galaxy" },
{ "HEZE",  13.530,   -0.330,    3.400,    0.090,
  59,    6,"White" },
{ "M-83",  13.570,  -29.620,    8.000, 10000.000,
  32,    0,"Spiral galaxy" },
{ "EPSILON CEN",  13.610,  -53.220,    2.300,    0.570,
  16,    5,"Blue" },
{ "M-3",  13.670,   28.630,    6.000,    4.000,
  10,    0,"Globular cluster" },
{ "NGC-5286",  13.720,  -51.120,    9.100,    0.000,
  16,    0,"Globular cluster" },
{ "TAU BOO",  13.750,   17.700,    4.500,    0.052,
   7,   19,"Yellow" },
{ "ALKAID",  13.760,   49.570,    1.900,    0.210,
  56,    7,"Brilliant white - Governor aka BENETNASCH" },
{ "MU CEN",  13.770,  -42.230,    3.100,    0.470,
  16,   12,"Blue double" },
{ "NU CEN",  13.770,  -41.430,    3.400,    0.750,
  16,   13,"Blue binary" },
{ "NGC-5316",  13.840,  -61.620,    8.400,    0.000,
  16,    0,"Spiral galaxy" },
{ "MUPHRID",  13.870,   18.650,    2.700,    0.032,
   7,    7,"Pale yellow - Solitary Star of the Lancer" },
{ "ZETA CEN",  13.870,  -47.050,    2.600,    0.520,
  16,    6,"Blue binary" },
{ "M-101",  14.020,   54.580,    9.000, 15000.000,
  56,    0,"Spiral galaxy" },
{ "THUBAN",  14.050,   64.620,    3.600,    0.215,
  27,    1,"White giant binary - Dragon" },
{ "HADAR",  14.050,  -60.130,    0.700,    0.490,
  16,    2,"Blue giant double" },
{ "MENKENT",  14.050,  -36.120,    2.000,    0.055,
  16,    8,"Orange giant" },
{ "PI HYA",  14.060,  -26.450,    3.300,    0.085,
  32,   16,"Orange giant" },
{ "ARCTURUS",  14.220,   19.450,   -0.060,    0.037,
   7,    1,"Golden yellow giant- Leg of the Lance Bearer" },
{ "SYRMA",  14.230,   -4.250,    4.200,    0.075,
  59,    9,"Yellow" },
{ "ASELLUS",  14.390,   51.860,    4.100,    0.050,
   7,    8,"Yellow" },
{ "SEGINUS",  14.500,   38.530,    3.000,    0.120,
   7,    3,"White giant - aka HARIS" },
{ "ETA CEN",  14.530,  -41.930,    2.400,    0.390,
  16,    7,"Blue" },
{ "RIGEL KENTAURUS",  14.600,  -60.630,    0.400,    0.004,
  16,    1,"Yellow triple - Proxima Centauri" },
{ "MEN",  14.640,  -47.170,    2.300,    0.430,
  36,    1,"Blue giant variable" },
{ "IZAR",  14.710,   27.280,    2.400,    0.300,
   7,    5,"Pale orange double - The Girdle - aka MIRAK" },
{ "MU LIB",  14.770,  -13.950,    5.500,    0.000,
  35,   12,"White binary" },
{ "ZUBEN EL GENUBI",  14.800,  -15.830,    2.800,    0.065,
  35,    1,"Pale yellow double - Southern Claw" },
{ "XI BOO",  14.820,   19.300,    4.500,    0.022,
   7,   14,"Yellow-orange binary" },
{ "KOCHAB",  14.850,   74.370,    2.100,    0.100,
  57,    2,"Reddish giant - Star of the North" },
{ "KW KOUAN",  14.920,  -42.930,    2.700,    0.540,
  36,    2,"Blue" },
{ "KAPPA CEN",  14.930,  -41.900,    3.200,    0.470,
  16,   10,"Blue binary" },
{ "DELTA LIB",  14.970,   -8.320,    4.800,    0.180,
  35,    4,"White variable" },
{ "NEKKAR",  15.000,   40.580,    3.500,    0.140,
   7,    2,"Golden yellow giant - Herdsman" },
{ "ZUBEN ALGUBI",  15.020,  -25.080,    3.300,    0.060,
  35,   18,"Red giant" },
{ "ZETA LUP",  15.130,  -51.920,    3.400,    0.090,
  36,    6,"Yellow-orange giant" },
{ "IOTA LIB",  15.160,  -19.600,    4.700,    0.250,
  35,    9,"White binary" },
{ "DELTA BOO",  15.220,   33.500,    3.500,    0.140,
   7,    4,"Yellow-orange giant" },
{ "ZUBEN ESCHAMALI",  15.230,   -9.200,    2.600,    0.140,
  35,    2,"Pale emerald - Northern Claw" },
{ "NGC-5897",  15.230,  -20.830,   10.000,    0.000,
  35,    0,"Globular cluster" },
{ "M-5",  15.270,    2.270,    6.000,   26.000,
  52,    0,"Globular cluster - NGC-5904" },
{ "DELTA LUP",  15.300,  -40.470,    3.200,    0.680,
  36,    4,"Blue" },
{ "EPSILON LUP",  15.320,  -44.520,    3.400,    0.300,
  36,    5,"Blue binary" },
{ "NGC-5921",  15.320,    5.250,   12.800,    0.000,
  52,    0,"Barred spiral galaxy" },
{ "PHERKAD",  15.340,   72.020,    3.100,    0.270,
  57,    3,"White giant - The Calf" },
{ "ETA CRB",  15.350,   30.470,    5.000,    0.000,
  21,    7,"Yellow binary" },
{ "ALKALUROPS",  15.370,   37.550,    4.500,    0.095,
   7,   12,"White double - Herdsmans Club or Staff" },
{ "ED ASICH",  15.400,   59.130,    3.300,    0.100,
  27,    9,"Orange giant" },
{ "NUSAKAN",  15.420,   29.280,    3.700,    0.100,
  21,    2,"Yellow binary" },
{ "GAMMA LUP",  15.530,  -41.000,    2.800,    0.570,
  36,    3,"Blue binary" },
{ "ALPHECCA",  15.540,   26.880,    2.200,    0.075,
  21,    1,"Brilliant white binary - A Bud - aka GEMMA" },
{ "DELTA SER",  15.540,   10.700,    4.000,    0.170,
  52,    4,"Yellow double" },
{ "ZUBEN EL AKRAB",  15.550,  -14.600,    4.000,    0.110,
  35,    3,"Orange" },
{ "UPSILON LIB",  15.570,  -27.970,    3.800,    0.135,
  35,   20,"Orange double" },
{ "IOTA SER",  15.650,   19.830,    5.000,    0.250,
  52,    9,"White binary" },
{ "GAMMA CRB",  15.670,   26.450,    3.900,    0.140,
  21,    3,"White double" },
{ "UNUK AL HAI",  15.690,    6.580,    2.700,    0.070,
  52,    1,"Yellow giant double - Neck of the Snake" },
{ "PSI SER",  15.690,    2.670,    5.900,    0.000,
  52,   23,"Multiple star" },
{ "BETA SER",  15.730,   15.580,    3.700,    0.095,
  52,    2,"White double" },
{ "XI UMI",  15.740,   77.670,    6.000,    0.000,
  57,   14," " },
{ "ALIFA",  15.740,   77.830,    4.300,    0.220,
  57,    6,"White" },
{ "PI SCO",  15.930,  -25.970,    2.900,    0.570,
  50,   16,"Blue" },
{ "ETA LUP",  15.940,  -38.250,    3.500,    0.570,
  36,    7,"Blue double" },
{ "T CRB",  15.960,   26.060,   10.000,    2.600,
  21,    0,"Recurrent Nova - Blaze Star" },
{ "DSCHUBBA",  15.960,  -22.480,    2.300,    0.590,
  50,    4,"Blue - Front of the Forehead" },
{ "XI SCO",  16.020,  -11.230,    4.200,    0.080,
  50,   14,"Yellow multiple" },
{ "AKRAB",  16.030,  -19.670,    2.600,    0.600,
  50,    2,"Pale white double - The Crab" },
{ "MARFIK",  16.090,   17.180,    5.000,    0.000,
  31,   10,"Yellow double - aka MARSIC" },
{ "JABBAH",  16.150,  -19.350,    4.300,    0.400,
  50,   13,"Quad star - Crown of the Forehead" },
{ "YED PRIOR",  16.190,   -3.570,    2.700,    0.140,
  40,    4,"Deep yellow giant - Star Following" },
{ "SIGMA CRB",  16.210,   33.980,    5.400,    0.070,
  21,   18,"Yellow double" },
{ "M-80",  16.230,  -22.870,    8.000,   36.000,
  50,    0,"Globular cluster" },
{ "YED POSTERIOR",  16.260,   -4.570,    3.200,    0.090,
  40,    5,"Yellow giant - Hand" },
{ "ETA UMI",  16.260,   75.770,    6.000,    0.000,
  57,    7," " },
{ "TAU HER",  16.300,   46.430,    4.000,    0.270,
  31,   19,"Blue double" },
{ "AL NIYAT",  16.300,  -25.480,    2.900,    0.900,
  50,   18,"White giant double -  Shield of the Heart" },
{ "M-4",  16.330,  -26.410,    7.400,   62.000,
  50,    0,"Globular cluster" },
{ "RHO OPH",  16.370,  -23.330,    5.000,    0.400,
  40,   17,"Blue multiple" },
{ "CUJAM",  16.380,   14.150,    4.500,    0.120,
  31,   24,"White - Club of Hercules" },
{ "ALDHIBAIN",  16.380,   61.630,    2.700,    0.075,
  27,    7,"Orange giant" },
{ "ANTARES",  16.440,  -26.320,    0.900,    0.520,
  50,    1,"Red supergiant - Rival of Mars" },
{ "MARFIC",  16.470,    2.100,    4.000,    0.190,
  40,   11,"White binary - Elbow" },
{ "KORNEPHORUS",  16.470,   21.600,    2.800,    0.105,
  31,    2,"Pale yellow giant - Arab name for Hercules" },
{ "TAU SCO",  16.540,  -28.120,    2.900,    0.750,
  50,   19,"Blue" },
{ "HAN",  16.570,  -10.470,    2.600,    0.520,
  40,    6,"Blue" },
{ "RUTILICUS",  16.650,   31.700,    2.800,    0.030,
  31,    6,"Yellow double" },
{ "M-13",  16.660,   36.550,    5.900,   25.000,
  31,    0,"Great globular cluster - Keystone of Hercules" },
{ "ETA HER",  16.690,   39.020,    3.500,    0.060,
  31,    7,"Yellow-orange giant" },
{ "M-12",  16.740,   -1.870,    8.000,   22.000,
  40,    0,"Globular cluster" },
{ "WEI",  16.780,  -34.200,    2.300,    0.065,
  50,    5,"Orange giant" },
{ "MU SCO",  16.800,  -37.970,    3.100,    0.520,
  50,   12,"Blue double" },
{ "NGC-6231",  16.840,  -41.720,    6.000,    5.700,
  50,    0,"Open cluster" },
{ "EPSILON UMI",  16.850,   82.120,    4.200,    0.300,
  57,    5,"Yellow binary" },
{ "GRAFFIAS",  16.850,  -42.280,    3.600,    5.700,
  50,    6,"Blue supergiant" },
{ "ZETA ARA",  16.900,  -55.920,    3.200,    0.090,
   4,    6,"Red-orange giant" },
{ "M-10",  16.910,   -4.030,    7.000,   22.000,
  40,    0,"Globular cluster" },
{ "KAPPA OPH",  16.920,    9.450,    3.200,    0.150,
  40,   10,"Orange giant" },
{ "M-62",  16.970,  -30.050,    6.500,   26.000,
  50,    0,"Globular cluster" },
{ "EPSILON HER",  16.970,   31.000,    3.900,    0.140,
  31,    5,"White" },
{ "M-19",  16.990,  -26.180,    7.000,    0.000,
  40,    0,"Globular cluster" },
{ "AL RAKIS",  17.070,   54.530,    5.100,    0.100,
  27,   12,"Yellow binary - Dancer" },
{ "SABIK",  17.120,  -15.670,    2.500,    0.070,
  40,    7,"Pale yellow binary" },
{ "ETA SCO",  17.130,  -43.180,    3.300,    0.050,
  50,    7,"Yellow giant" },
{ "ALDIBAH",  17.140,   65.780,    3.200,    0.600,
  27,    6,"Blue-white giant" },
{ "RAS ALGETHI",  17.210,   14.450,    3.100,    0.430,
  31,    1,"Red giant variable - Head of the Kneeler" },
{ "SARIN",  17.220,   24.900,    3.100,    0.095,
  31,    4,"White double" },
{ "PI HER",  17.220,   36.870,    3.100,    0.400,
  31,   16,"Orange giant" },
{ "M-92",  17.260,   43.200,    6.500,   35.000,
  31,    0,"Globular cluster" },
{ "M-9",  17.270,  -18.470,    8.000,   26.000,
  40,    0,"Globular cluster" },
{ "XI OPH",  17.300,  -21.050,    4.500,    0.050,
  40,   14,"Yellow double" },
{ "NU SER",  17.300,  -12.800,    4.500,    0.150,
  53,   13,"White double" },
{ "THETA OPH",  17.310,  -24.950,    3.300,    0.700,
  40,    8,"Blue" },
{ "BETA ARA",  17.350,  -55.480,    2.800,    1.030,
   4,    2,"Orange supergiant" },
{ "GAMMA ARA",  17.350,  -56.330,    3.300,    0.680,
   4,    3,"Blue giant" },
{ "RHO HER",  17.370,   37.180,    4.500,    0.270,
  31,   17,"White double" },
{ "LESUTH",  17.460,  -37.250,    2.700,    0.540,
  50,   20,"Blue supergiant - The Sting" },
{ "CHOO",  17.470,  -49.830,    2.900,    0.390,
   4,    1,"Blue binary" },
{ "RASTABAN",  17.480,   52.330,    2.800,    0.300,
  27,    2,"Yellow giant - Dragon Head - aka ALWAID" },
{ "SHAULA",  17.500,  -37.060,    1.600,    0.310,
  50,   11,"Blue - The Sting" },
{ "KUMA",  17.520,   55.220,    4.900,    0.120,
  27,   13,"Yellow double" },
{ "RAS ALHAGUE",  17.540,   12.600,    2.100,    0.060,
  40,    1,"White giant - Head of the Serpent Charmer" },
{ "MASYM",  17.550,   25.990,    4.500,    0.230,
  31,   11,"Deep yellow - The Wrist" },
{ "SARGAS",  17.560,  -42.970,    1.900,    0.650,
  50,    8,"Red - The Siezer" },
{ "M-14",  17.580,   -3.220,    9.000,   70.000,
  40,    0,"Globular cluster" },
{ "M-6",  17.610,  -32.180,    6.100,    2.000,
  50,    0,"Open cluster" },
{ "OMICRON SER",  17.640,  -12.850,    4.200,    0.300,
  53,   15,"White variable" },
{ "GIRTAB",  17.650,  -39.000,    2.400,    0.470,
  50,   10,"Blue variable" },
{ "CHELEB",  17.680,    4.580,    2.800,    0.125,
  40,    2,"Yellow giant - The Shepherds Dog" },
{ "DSIBAN",  17.710,   72.180,    5.000,    0.000,
  27,   23,"Yellow double" },
{ "YILDUN",  17.720,   86.600,    4.400,    0.330,
  57,    4,"Green - aka PHERKARD" },
{ "MU HER",  17.730,   27.750,    3.400,    0.030,
  31,   12,"Yellow triple" },
{ "IOTA SCO",  17.730,  -40.110,    3.000,    3.400,
  50,    9,"Yellow supergiant" },
{ "M-7",  17.840,  -34.800,    5.000,    0.800,
  50,    0,"Open cluster" },
{ "M-23",  17.910,  -19.020,    6.900,    2.000,
  49,    0,"Open cluster" },
{ "ELTANIN",  17.920,   51.500,    2.200,    0.110,
  27,    3,"Orange - Dragons Head - aka RASABEN" },
{ "NU OPH",  17.930,   -9.770,    3.300,    0.140,
  40,   13,"Yellow-orange giant" },
{ "M-20",  17.980,  -23.030,    6.000,    6.500,
  49,    0,"Diffuse nebula - Trifid Nebula" },
{ "TAU OPH",  18.000,   -8.180,    5.000,    0.000,
  40,   19,"Yellow binary" },
{ "M-8",  18.020,  -24.330,    5.000,    5.150,
  49,    0,"Lagoon Nebula" },
{ "NGC-6530",  18.020,  -24.330,    6.900,    0.000,
  49,    0,"Open cluster" },
{ "M-21",  18.030,  -22.500,    7.000,    2.200,
  49,    0,"Open cluster" },
{ "EL NASL",  18.040,  -30.430,    3.000,    0.125,
  49,    3,"Yellow giant - Point Head of the Arrow" },
{ "NGC-6544",  18.070,  -25.010,    9.000,    0.000,
  49,    0,"Globular cluster" },
{ "OMICRON HER",  18.080,   28.750,    4.100,    0.250,
  31,   15,"Blue variable" },
{ "IC-4681",  18.080,  -23.450,    9.000,    0.000,
  49,    0,"Diffuse nebula" },
{ "NGC-6553",  18.100,  -25.930,   10.000,    0.000,
  49,    0,"Globular cluster" },
{ "NGC-6559",  18.100,  -24.130,   10.000,    0.000,
  49,    0,"Diffuse nebula" },
{ "MU SGR",  18.170,  -21.080,    4.000,    3.300,
  49,   12,"Blue binary" },
{ "JUZA",  18.200,   56.790,    3.900,    0.105,
  27,   14,"Yellow - Underjaw of the Dragon" },
{ "ARKAP",  18.230,  -36.780,    3.000,    0.090,
  49,    7,"Orange giant double" },
{ "M-16",  18.270,  -13.800,    6.400,    8.000,
  53,    0,"Open cluster - Eagle Nebula" },
{ "M-18",  18.280,  -17.150,    8.000,    4.900,
  49,    0,"Open cluster" },
{ "MEDIA",  18.290,  -29.850,    2.700,    0.085,
  49,    4,"Orange giant - Middle of the Bow" },
{ "ETA SER",  18.310,   -2.920,    3.300,    0.060,
  53,    7,"Orange giant" },
{ "M-17",  18.310,  -16.200,    6.000,    5.700,
  49,    0,"Omega or Swan or Horseshoe Nebula" },
{ "KAUS AUSTRALIS",  18.340,  -34.420,    1.800,    0.125,
  49,    5,"Blue-white - Southern Part of the Bow" },
{ "M-28",  18.360,  -24.900,    8.000,   15.000,
  49,    0,"Globular cluster" },
{ "KAUS BOREALIS",  18.410,  -25.450,    2.800,    0.070,
  49,   11,"Yellow giant - Northern Part of the Bow" },
{ "M-69",  18.470,  -32.380,    7.500,   36.000,
  49,    0,"Globular cluster" },
{ "NGC-6642",  18.480,  -23.520,    8.000,    0.000,
  49,    0,"Globular cluster" },
{ "M-22",  18.550,  -23.970,    5.900,   22.000,
  49,    0,"Great globular cluster" },
{ "VEGA",  18.580,   38.730,    0.040,    0.027,
  38,    1,"Pale sapphire - The Harp Star" },
{ "DELTA SCT",  18.660,   -9.100,    4.700,    0.250,
  51,    4,"Yellow giant variable" },
{ "M-70",  18.670,  -32.350,    8.000,   95.000,
  49,    0,"Globular cluster" },
{ "PHI SGR",  18.710,  -27.050,    3.200,    0.590,
  49,   21,"Blue-white giant" },
{ "EPSILON LYR",  18.710,   39.620,    5.500,    0.180,
  38,    5,"Double star - The Double Double" },
{ "M-26",  18.710,   -9.450,    9.500,    4.900,
  51,    0,"Open cluster" },
{ "SHELIAK",  18.800,   33.300,    3.400,    0.860,
  38,    2,"White - Tortoise" },
{ "M-11",  18.810,   -6.330,    6.100,    5.500,
  51,    0,"Open cluster - The Wild Duck Cluster" },
{ "M-57",  18.850,   32.970,    8.800,    1.400,
  38,    0,"Planetary nebula - The Ring Nebula" },
{ "M-54",  18.870,  -30.530,    9.000,   50.000,
  49,    0,"Globular cluster" },
{ "DELTA LYR",  18.870,   36.840,    4.500,    0.800,
  38,    4,"Red giant double" },
{ "NUNKI",  18.870,  -26.370,    2.100,    0.300,
  49,   18,"Blue - Star of the Proclamation of the Sea" },
{ "ALYA",  18.890,    4.130,    3.000,    0.130,
  53,    8,"White double - Serpent" },
{ "XI SGR",  18.910,  -21.170,    3.500,    0.160,
  49,   14,"Orange giant" },
{ "EPSILON AQL",  18.920,   14.890,    4.200,    0.145,
   3,    5,"Orange" },
{ "SULAFAT",  18.950,   32.620,    3.300,    0.370,
  38,    3,"White giant - Tortoise" },
{ "ASCELLA",  18.990,  -29.950,    2.600,    0.140,
  49,    6,"White giant binary - Armpit" },
{ "DENEB AL OKAB",  19.050,   13.780,    3.000,    0.090,
   3,    6,"White double - Tail of the Eagle" },
{ "ALTHALIMAIN",  19.060,   -4.970,    3.400,    0.160,
   3,   11,"Blue-white" },
{ "TAU SGR",  19.060,  -27.750,    3.300,    0.085,
  49,   19,"Orange giant" },
{ "NGC-6752",  19.100,  -60.070,    7.200,   20.000,
  42,    0,"Globular cluster" },
{ "ALBALDAH",  19.110,  -21.100,    2.900,    0.250,
  49,   16,"Yellow giant triple" },
{ "ALADFAR",  19.160,   38.990,    4.500,    0.800,
  38,    7,"Blue" },
{ "ALDIB",  19.210,   67.570,    3.100,    0.120,
  27,    4,"Orange giant - Second Knot - aka NODUS SECUNDUS" },
{ "M-56",  19.230,   30.080,    8.200,   46.000,
  38,    0,"Globular cluster" },
{ "UPSILON SGR",  19.310,  -16.050,    4.400,    8.000,
  49,   20,"Blue binary variable" },
{ "ARKAB",  19.320,  -44.550,    4.000,    0.270,
  49,    2,"Blue double - Tendon" },
{ "RUKBAT",  19.320,  -39.450,    4.100,    0.250,
  49,    1,"Blue - Knee of the Archer" },
{ "NGC-6791",  19.320,   37.670,   11.000,    0.000,
  38,    0,"Open cluster" },
{ "DELTA AQL",  19.380,    3.020,    3.400,    0.053,
   3,    4,"Yellow" },
{ "ALBIREO",  19.470,   27.850,    3.100,    0.410,
  24,    2,"Yellow-green giant double - Nose of the Swan" },
{ "SIGMA AQL",  19.600,    5.280,    5.100,    0.950,
   3,   18,"Blue binary" },
{ "M-55",  19.610,  -31.050,    7.000,   20.000,
  49,    0,"Globular cluster" },
{ "NGC-6822",  19.700,  -14.880,   11.000, 1700.000,
  49,    0,"Barnards Galaxy" },
{ "TARAZED",  19.720,   10.480,    2.700,    0.340,
   3,    3,"Pale orange giant - Soaring Falcon" },
{ "SADOR",  19.720,   45.000,    2.900,    0.270,
  24,    4,"Blue-white giant" },
{ "TYL",  19.760,   70.160,    4.000,    0.250,
  27,    5,"Orange" },
{ "ALTAIR",  19.800,    8.700,    0.800,    0.016,
   3,    1,"White - Flying Eagle" },
{ "ETA AQL",  19.830,    0.870,    3.800,    1.300,
   3,    7,"Yellow variable" },
{ "ALSCHAIN",  19.880,    6.280,    3.700,    0.040,
   3,    2,"Yellow-orange double" },
{ "ETA CYG",  19.910,   34.900,    4.000,    0.190,
  24,    7,"Orange" },
{ "M-27",  19.960,   22.580,    8.000,    0.900,
  60,    0,"Planetary nebula - Dumb-bell Nebula" },
{ "M-75",  20.050,  -22.060,    8.000,   95.000,
  49,    0,"Globular cluster" },
{ "THETA AQL",  20.140,   -0.970,    3.250,    0.325,
   3,    8,"Blue-white giant binary" },
{ "AL GIEDI",  20.250,  -12.700,    3.600,    0.100,
  13,    1,"Yellow-orange double - Head of the Goat" },
{ "DABIH",  20.300,  -14.930,    3.100,    0.150,
  13,    2,"Yellow triple - Lucky Star of the Slayer" },
{ "SADR",  20.340,   40.100,    2.200,    0.750,
  24,    3,"Yellow supergiant - Hens Breast" },
{ "PEACOCK",  20.350,  -56.900,    1.900,    0.310,
  42,    2,"Blue" },
{ "NGC-6939",  20.500,   60.470,   12.000,    0.000,
  17,    0,"Open cluster" },
{ "NGC-6946",  20.560,   59.970,   11.000, 15000.000,
  17,    0,"Spiral galaxy" },
{ "ROTANEV",  20.580,   14.420,    3.800,    0.125,
  25,    2,"Yellow double - Venator spelled backward" },
{ "SUALOCIN",  20.610,   15.690,    3.900,    0.270,
  25,    1,"Pale yellow - Nicolaus spelled backward" },
{ "DENEB",  20.660,   45.100,    1.300,    1.600,
  24,    1,"Brilliant white supergiant - Hindmost" },
{ "BETA PAV",  20.670,  -66.380,    3.400,    0.160,
  42,    2,"White" },
{ "GAMMA DEL",  20.730,   15.950,    3.900,    0.100,
  25,    3,"Orange double" },
{ "GIENA",  20.730,   33.780,    2.500,    0.075,
  24,    5,"Yellow giant - The Wing" },
{ "ETA CEP",  20.730,   61.650,    3.400,    0.046,
  17,    7,"Orange" },
{ "SITULA",  20.730,   -5.040,    4.600,    0.350,
   2,   10,"Red - Water Jar" },
{ "AL BALI",  20.750,   -9.680,    3.800,    0.170,
   2,    5,"White - Good Fortune of the Swallower" },
{ "M-72",  20.840,  -12.730,    8.600,   60.000,
   2,    0,"Globular cluster" },
{ "NGC-6992",  20.900,   31.500,   10.000,    1.500,
  24,    0,"Supernova remnant - Veil Nebula" },
{ "M-73",  20.930,  -12.850,   10.000,    0.000,
   2,    0,"Triangle of three stars" },
{ "NGC-7000",  20.950,   44.130,   10.000,    0.000,
  24,    0,"North American Nebula" },
{ "NGC-7009",  21.000,  -11.560,    8.000,    3.900,
   2,    0,"Bluish-green planetary nebula - The Saturn Nebula" },
{ "NGC-7023",  21.020,   67.970,    7.000,    0.000,
  17,    0,"Diffuse nebula" },
{ "ZETA CYG",  21.180,   30.020,    3.200,    0.390,
  24,    6,"Yellow-orange giant" },
{ "TAU CYG",  21.210,   37.820,    3.700,    0.075,
  24,   19,"Yellow binary" },
{ "ALDERAMIN",  21.280,   62.370,    2.500,    0.052,
  17,    1,"White - Right Arm" },
{ "M-15",  21.470,   11.950,    6.400,   39.000,
  43,    0,"Globular cluster" },
{ "ALFIRK",  21.470,   70.330,    3.200,    0.980,
  17,    2,"White binary - Stars of the Flock" },
{ "SADALSUND",  21.480,   -5.800,    2.900,    1.030,
   2,    2,"Pale yellow supergiant - Luckiest of the Lucky" },
{ "M-39",  21.500,   48.220,    5.000,    0.800,
  24,    0,"Open cluster" },
{ "M-2",  21.510,   -1.060,    6.000,   50.000,
   2,    0,"Globular cluster" },
{ "IC-1396",  21.600,   57.360,    5.600,    0.000,
  17,    0,"Diffuse nebula" },
{ "NASHIRA",  21.620,  -15.380,    3.800,    0.107,
  13,    3,"Yellow - Fortunate One" },
{ "M-30",  21.620,  -23.420,    8.600,   40.000,
  13,    0,"Globular cluster" },
{ "ENIF",  21.680,    9.650,    2.300,    0.780,
  43,    5,"Yellow supergiant - Arabic for Nose" },
{ "MU CYG",  21.690,   28.520,    4.500,    0.065,
  24,   12,"Yellow binary" },
{ "KAPPA PEG",  21.700,   25.420,    4.300,    0.100,
  43,   10,"Yellow binary" },
{ "MU CEP",  21.700,   58.550,    4.000,    1.000,
  17,   12,"Red supergiant - Garnet Star" },
{ "AZELFAFAGE",  21.740,   49.110,    4.700,    0.800,
  24,   16,"Blue - Foot of the Horse" },
{ "DENEB ALGIEDI",  21.750,  -16.350,    2.800,    0.050,
  13,    4,"Yellow binary - Tail of the Goat" },
{ "GAMMA GRU",  21.840,  -37.600,    3.000,    0.540,
  30,    3,"Blue-white giant" },
{ "KURDAH",  22.020,   64.380,    4.300,    0.080,
  17,   14,"White double" },
{ "SADALMELIK",  22.050,   -0.560,    2.900,    1.100,
   2,    1,"Orange supergiant - Lucky Star of the King" },
{ "AL NAIR",  22.080,  -47.200,    1.800,    0.065,
  30,    1,"Blue" },
{ "BIHAM",  22.130,    5.940,    3.700,    0.080,
  43,    8,"White - Young of Domestic Animals" },
{ "ZETA CEP",  22.150,   57.950,    3.400,    1.240,
  17,    6,"Orange supergiant" },
{ "EPSILON CEP",  22.220,   56.800,    4.200,    0.085,
  17,    5,"Yellow" },
{ "ANCHA",  22.240,   -6.260,    4.200,    0.190,
   2,    8,"Orange - The Hip" },
{ "ALPHA TUC",  22.250,  -60.520,    2.900,    0.062,
  55,    1,"Orange giant" },
{ "SADACHBIA",  22.320,   -1.630,    3.800,    0.095,
   2,    3,"White giant - Lucky Star of Hidden Things" },
{ "ZETA AQR",  22.430,   -0.280,    3.700,    0.075,
   2,    6,"Yellow binary - part of Water Jar" },
{ "DELTA CEP",  22.450,   58.170,    4.000,    1.000,
  17,    4,"Yellow giant variable double" },
{ "NGC-7293",  22.450,  -21.100,    6.500,    0.045,
   2,    0,"Planetary nebula - The Helix" },
{ "BETA PSA",  22.480,  -32.600,    4.500,    0.220,
  47,    2,"White double" },
{ "NGC-7331",  22.580,   34.170,   10.300,    0.000,
  43,    0,"Spiral galaxy - Similar to Milky Way System" },
{ "AL DHANAB",  22.650,  -47.150,    2.200,    0.280,
  30,    2,"Red giant" },
{ "HOMAM",  22.650,   10.570,    3.500,    0.210,
  43,    6,"White - Lucky Star of the Hero" },
{ "MATAR",  22.670,   29.970,    3.000,    0.360,
  43,    7,"Yellow-orange giant - Fortunate Rain" },
{ "LAMBDA PEG",  22.730,   23.310,    4.100,    0.150,
  43,   11,"Orange" },
{ "SAD AL BARI",  22.790,   24.330,    3.500,    0.100,
  43,   12,"Yellow giant - Good Luck of the Excelling One" },
{ "GAMMA PSA",  22.830,  -33.130,    4.500,    0.180,
  47,    3,"White double" },
{ "SKAT",  22.870,  -16.080,    3.300,    0.085,
   2,    4,"white - Wish or Shin Bone" },
{ "DELTA PSA",  22.880,  -32.800,    4.500,    0.180,
  47,    4,"Yellow double" },
{ "FOMALHAUT",  22.910,  -29.880,    1.200,    0.023,
  47,    1,"White - Autumn Star - Mouth of the Fish" },
{ "OMICRON AND",  22.980,   42.050,    3.600,    0.500,
   1,   15,"Blue-white variable" },
{ "SCHEAT",  23.020,   27.820,    2.500,    0.210,
  43,    2,"Red variable - Upper Part of the Arm" },
{ "MARKAB",  23.030,   14.930,    2.500,    0.110,
  43,    1,"White giant - Saddle" },
{ "PSI AQR",  23.220,   -8.940,    4.500,    0.120,
   2,   23,"Orange double" },
{ "NGC-7635",  23.310,   60.900,   11.100,    0.000,
  15,    0,"Planetary nebula - Bubble Nebula" },
{ "M-52",  23.370,   61.330,    7.300,   65.000,
  15,    0,"Open cluster" },
{ "LAMBDA AND",  23.580,   46.180,    3.900,    0.080,
   1,   11,"Orange binary" },
{ "ER RAI",  23.620,   77.350,    3.200,    0.050,
  17,    3,"Orange - Shepherd" },
};

/* Greek letters used in star names */
char *Greek[MAXGREEK] = {
"FOUND IN","ALPHA","BETA","GAMMA","DELTA","EPSILON","ZETA","ETA","THETA",
"IOTA","KAPPA","LAMBDA","MU","NU","XI","OMICRON","PI","RHO","SIGMA","TAU",
"UPSILON","PHI","CHI","PSI","OMEGA",
};



/* Table of constellation names, abbreviations and meanings */
struct cons_rec Constel[MAXCONS] = {
{" "," "," "}, /* Dummy zero record */
{ "ANDROMEDA",  "AND",  "CHAINED MAIDEN" },
{ "AQUARIUS",  "AQR",  "WATER CARRIER" },
{ "AQUILA",  "AQL",  "EAGLE" },
{ "ARA",  "ARA",  "ALTAR" },
{ "ARIES",  "ARI",  "RAM" },
{ "AURIGA",  "AUR",  "CHARIOTEER" },
{ "BOOTES",  "BOO",  "HERDSMAN" },
{ "CAMELOPARDALIS",  "CAM",  "GIRAFFE" },
{ "CANCER",  "CNC",  "CRAB" },
{ "CANES VENATICI",  "CVN",  "HUNTING DOGS" },
{ "CANIS MAJOR",  "CMA",  "GREAT DOG" },
{ "CANIS MINOR",  "CMI",  "LESSER DOG" },
{ "CAPRICORN",  "CAP",  "SEA GOAT" },
{ "CARINA",  "CAR",  "KEEL" },
{ "CASSIOPEIA",  "CAS",  "QUEEN" },
{ "CENTAURUS",  "CEN",  "CENTAUR" },
{ "CEPHEUS",  "CEP",  "KING" },
{ "CETUS",  "CET",  "WHALE" },
{ "COLUMBA",  "COL",  "DOVE" },
{ "COMA BERENICES",  "COM",  "BERENICES HAIR" },
{ "CORONA BOREALIS",  "CRB",  "NORTHERN CROWN" },
{ "CORVUS",  "CRV",  "CROW" },
{ "CRUX",  "CRU",  "SOUTHERN CROSS" },
{ "CYGNUS",  "CYG",  "SWAN" },
{ "DELPHINUS",  "DEL",  "DOLPHIN" },
{ "DORADO",  "DOR",  "DORADO" },
{ "DRACO",  "DRA",  "DRAGON" },
{ "ERIDANUS",  "ERI",  "RIVER" },
{ "GEMINI",  "GEM",  "TWINS" },
{ "GRUS",  "GRU",  "CRANE" },
{ "HERCULES",  "HER",  " " },
{ "HYDRA",  "HYA",  "WATER MONSTER" },
{ "LEO",  "LEO",  "LION" },
{ "LEPUS",  "LEP",  "HARE" },
{ "LIBRA",  "LIB",  "SCALES" },
{ "LUPUS",  "LUP",  "WOLF" },
{ "LYNX",  "LYN",  "LYNX" },
{ "LYRA",  "LYR",  "LYRE" },
{ "MONOCEROS",  "MON",  "UNICORN" },
{ "OPHIUCHUS",  "OPH",  "SERPENT BEARER" },
{ "ORION",  "ORI",  "HUNTER" },
{ "PAVO",  "PAV",  "PEACOCK" },
{ "PEGASUS",  "PEG",  "WINGED HORSE" },
{ "PERSEUS",  "PER",  "HERO" },
{ "PHOENIX",  "PHE",  "PHOENIX" },
{ "PISCES",  "PSC",  "FISH" },
{ "PISCES AUSTRINUS",  "PSA",  "SOUTHERN FISH" },
{ "PUPPIS",  "PUP",  "STERN" },
{ "SAGITTARIUS",  "SGR",  "ARCHER" },
{ "SCORPIUS",  "SCO",  "SCORPION" },
{ "SCUTUM",  "SCT",  "SHIELD" },
{ "SERPENS CAPUT",  "SER",  "SERPENTS HEAD" },
{ "SERPENS CAUDA",  "SER",  "SERPENTS TAIL" },
{ "TAURUS",  "TAU",  "BULL" },
{ "TUCANA",  "TUC",  "TOUCAN" },
{ "URSA MAJOR",  "UMA",  "GREAT BEAR - AKA Big Dipper" },
{ "URSA MINOR",  "UMI",  "LESSER BEAR - AKA Little Dipper" },
{ "VELA",  "VEL",  "SAIL" },
{ "VIRGO",  "VIR",  "VIRGIN" },
{ "VULPECULA",  "VUL",  "LITTLE FOX" },
};
